@@ -245,13 +245,15 @@ class SecretsManagerClient(BaseClient):
     def list_secrets(
         self,
         *,
+        IncludePlannedDeletion: bool = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
         Filters: Sequence[FilterTypeDef] = ...,
         SortOrder: SortOrderTypeType = ...
     ) -> ListSecretsResponseTypeDef:
         """
-        .
+        Lists the secrets that are stored by Secrets Manager in the Amazon Web Services
+        account, not including secrets that are marked for deletion.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/secretsmanager.html#SecretsManager.Client.list_secrets)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/client/#list_secrets)
