@@ -667,6 +667,7 @@ DescribeSecretResponseTypeDef = TypedDict(
         "LastChangedDate": datetime,
         "LastAccessedDate": datetime,
         "DeletedDate": datetime,
+        "NextRotationDate": datetime,
         "Tags": List[TagTypeDef],
         "VersionIdsToStages": Dict[str, List[str]],
         "OwningService": str,
@@ -715,6 +716,7 @@ SecretListEntryTypeDef = TypedDict(
         "LastChangedDate": datetime,
         "LastAccessedDate": datetime,
         "DeletedDate": datetime,
+        "NextRotationDate": datetime,
         "Tags": List[TagTypeDef],
         "SecretVersionsToStages": Dict[str, List[str]],
         "OwningService": str,
@@ -727,6 +729,7 @@ SecretListEntryTypeDef = TypedDict(
 ListSecretsRequestRequestTypeDef = TypedDict(
     "ListSecretsRequestRequestTypeDef",
     {
+        "IncludePlannedDeletion": bool,
         "MaxResults": int,
         "NextToken": str,
         "Filters": Sequence[FilterTypeDef],
@@ -749,6 +752,7 @@ ListSecretVersionIdsResponseTypeDef = TypedDict(
 ListSecretsRequestListSecretsPaginateTypeDef = TypedDict(
     "ListSecretsRequestListSecretsPaginateTypeDef",
     {
+        "IncludePlannedDeletion": bool,
         "Filters": Sequence[FilterTypeDef],
         "SortOrder": SortOrderTypeType,
         "PaginationConfig": PaginatorConfigTypeDef,
